# Installation

`$ pip install gardnr`


# Documentation

[https://gardnr.readthedocs.io](https://gardnr.readthedocs.io)

## Building Documentation

Documentation is stored in the `docs` directory in ReST syntax and built using Sphinx. To build the documentation HTML pages, run `$ sphinx-build -b html docs docs/build`. To view the built documentation, open a browser to `docs/build/index.html` in repository.
